use sea_orm_migration::prelude::*;

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(Day::Table)
                    .if_not_exists()
                    .col(ColumnDef::new(Day::Day).date().not_null().primary_key())
                    .col(
                        ColumnDef::new(Day::PlannedAmountCox)
                            .not_null()
                            .integer()
                            .default(0),
                    )
                    .col(ColumnDef::new(Day::PlannedStartingTime).string())
                    .col(
                        ColumnDef::new(Day::OpenRegistration)
                            .boolean()
                            .not_null()
                            .default(true),
                    )
                    .to_owned(),
            )
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .drop_table(Table::drop().table(Day::Table).to_owned())
            .await
    }
}

/// Learn more at https://docs.rs/sea-query#iden
#[derive(Iden)]
pub enum Day {
    Table,
    Day,
    PlannedAmountCox,
    PlannedStartingTime,
    OpenRegistration,
}
